==> fasc-openapi-java-sdk-5.2.2-sources.jar: com/fasc/open/api/v5_1/req/signtask/CreateSignTaskBaseReq.java <==
package com.fasc.open.api.v5_1.req.signtask;

import com.fasc.open.api.bean.base.BaseReq;
import com.fasc.open.api.bean.common.OpenId;

/**
 * @author Fadada
 * 2021/9/13 11:40:45
 */
public class CreateSignTaskBaseReq extends BaseReq {
    private String signTaskSubject;
    private String signDocType;
    private OpenId initiator;
    private String expiresTime;
    private Boolean autoStart;
    private Boolean autoFillFinalize;
    private String certCAOrg;
    private BusinessSceneInfo businessScene;
    private Boolean autoFinish;
    private String catalogId;
    private Long businessTypeId;
    private String businessCode;

    public String getSignDocType() {
        return signDocType;
    }

    public void setSignDocType(String signDocType) {
        this.signDocType = signDocType;
    }

    public String getSignTaskSubject() {
        return signTaskSubject;
    }

    public void setSignTaskSubject(String signTaskSubject) {
        this.signTaskSubject = signTaskSubject;
    }

    public OpenId getInitiator() {
        return initiator;
    }

    public void setInitiator(OpenId initiator) {
        this.initiator = initiator;
    }

    public String getExpiresTime() {
        return expiresTime;
    }

    public void setExpiresTime(String expiresTime) {
        this.expiresTime = expiresTime;
    }

    public Boolean getAutoFillFinalize() {
        return autoFillFinalize;
    }

    public void setAutoFillFinalize(Boolean autoFillFinalize) {
        this.autoFillFinalize = autoFillFinalize;
    }

    public BusinessSceneInfo getBusinessScene() {
        return businessScene;
    }

    public void setBusinessScene(BusinessSceneInfo businessScene) {
        this.businessScene = businessScene;
    }

    public Boolean getAutoStart() {
        return autoStart;
    }

    public void setAutoStart(Boolean autoStart) {
        this.autoStart = autoStart;
    }

    public String getCertCAOrg() {
        return certCAOrg;
    }

    public void setCertCAOrg(String certCAOrg) {
        this.certCAOrg = certCAOrg;
    }

    public Boolean getAutoFinish() {
        return autoFinish;
    }

    public void setAutoFinish(Boolean autoFinish) {
        this.autoFinish = autoFinish;
    }

    public String getCatalogId() {
        return catalogId;
    }

    public void setCatalogId(String catalogId) {
        this.catalogId = catalogId;
    }

    public Long getBusinessTypeId() {
        return businessTypeId;
    }

    public void setBusinessTypeId(Long businessTypeId) {
        this.businessTypeId = businessTypeId;
    }

    public String getBusinessCode() {
        return businessCode;
    }

    public void setBusinessCode(String businessCode) {
        this.businessCode = businessCode;
    }
}

==> fasc-openapi-java-sdk-5.2.5.2-sources.jar: com/fasc/open/api/v5_1/req/signtask/CreateSignTaskBaseReq.java <==
package com.fasc.open.api.v5_1.req.signtask;

import com.fasc.open.api.bean.base.BaseReq;
import com.fasc.open.api.bean.common.OpenId;

/**
 * @author Fadada
 * 2021/9/13 11:40:45
 */
public class CreateSignTaskBaseReq extends BaseReq {
    private String signTaskSubject;
    private String signDocType;
    private OpenId initiator;
    private String expiresTime;
    private Boolean autoStart;
    private Boolean autoFillFinalize;
    private String certCAOrg;
    private BusinessSceneInfo businessScene;
    private Boolean autoFinish;
    private String catalogId;
    private Long businessTypeId;
    private String businessCode;
    private Long initiatorMemberId;

    public String getSignDocType() {
        return signDocType;
    }

    public void setSignDocType(String signDocType) {
        this.signDocType = signDocType;
    }

    public String getSignTaskSubject() {
        return signTaskSubject;
    }

    public void setSignTaskSubject(String signTaskSubject) {
        this.signTaskSubject = signTaskSubject;
    }

    public OpenId getInitiator() {
        return initiator;
    }

    public void setInitiator(OpenId initiator) {
        this.initiator = initiator;
    }

    public String getExpiresTime() {
        return expiresTime;
    }

    public void setExpiresTime(String expiresTime) {
        this.expiresTime = expiresTime;
    }

    public Boolean getAutoFillFinalize() {
        return autoFillFinalize;
    }

    public void setAutoFillFinalize(Boolean autoFillFinalize) {
        this.autoFillFinalize = autoFillFinalize;
    }

    public BusinessSceneInfo getBusinessScene() {
        return businessScene;
    }

    public void setBusinessScene(BusinessSceneInfo businessScene) {
        this.businessScene = businessScene;
    }

    public Boolean getAutoStart() {
        return autoStart;
    }

    public void setAutoStart(Boolean autoStart) {
        this.autoStart = autoStart;
    }

    public String getCertCAOrg() {
        return certCAOrg;
    }

    public void setCertCAOrg(String certCAOrg) {
        this.certCAOrg = certCAOrg;
    }

    public Boolean getAutoFinish() {
        return autoFinish;
    }

    public void setAutoFinish(Boolean autoFinish) {
        this.autoFinish = autoFinish;
    }

    public String getCatalogId() {
        return catalogId;
    }

    public void setCatalogId(String catalogId) {
        this.catalogId = catalogId;
    }

    public Long getBusinessTypeId() {
        return businessTypeId;
    }

    public void setBusinessTypeId(Long businessTypeId) {
        this.businessTypeId = businessTypeId;
    }

    public String getBusinessCode() {
        return businessCode;
    }

    public void setBusinessCode(String businessCode) {
        this.businessCode = businessCode;
    }

    public Long getInitiatorMemberId() {
        return initiatorMemberId;
    }

    public void setInitiatorMemberId(Long initiatorMemberId) {
        this.initiatorMemberId = initiatorMemberId;
    }
}
